@@ -70,7 +70,7 @@ class Lens(Graph):
         if isinstance(resource, URIRef):
             elem.set("about", resource)
         elif isinstance(resource, BNode):
-            elem.set("typeof", RDFS["Resource"])
+            elem.set("about", "[_:%s]" % resource)
 
         log.debug("    Resource: %s" % resource)
         if isinstance(resource, URIRef):
@@ -167,30 +167,31 @@ class Lens(Graph):
         pcurie = "%s:%s" % (ns, local)
 
         if isinstance(value, Literal):
-            p = ET.Element("div")
-            p.set("rel", pcurie)
+            elem.set("property", pcurie)
+            elem.set("content", value)
             if value.language:
                 sp = ET.Element("span")
                 sp.set("class", "fresnel_object_language")
                 sp.text = u" (%s) " % value.language
-                p.append(sp)
-                self.rst(p, value)
+                elem.append(sp)
+                self.rst(elem, value)
             elif value.datatype:
                 if value.datatype == XSD["dateTime"]:
                     try:
                         dt = datetime.strptime(value, "%Y-%m-%dT%H:%M:%S.%f")
-                        p.text = dt.ctime()
+                        elem.text = dt.ctime()
                     except:
-                        p.text = value
+                        elem.text = value
                 else:
-                    p.text = value
+                    elem.text = value
             else:
-                self.rst(p, value)
-            elem.append(p)
+                self.rst(elem, value)
         elif isinstance(value, URIRef) or isinstance(value, BNode):
             elem.set("rel", pcurie)
             if isinstance(value, URIRef):
-                elem.set("href", value)
+                elem.set("resource", value)
+            else:
+                elem.set("resource", "[_:%s]" % value)
             if lens:
                 styles, rsrc = lens.formatResource(graph, value)
                 [stylesheets.add(x) for x in styles]
@@ -438,12 +439,10 @@ class Render(Command):
             doc += ET.tostring(child, encoding="utf-8")
         doc += '</html>'
 
-        print doc
-
-#        from xml.dom import minidom
-#        from StringIO import StringIO
-#        doc = minidom.parse(StringIO(doc))
-#        print doc.toprettyxml()
+        from xml.dom import minidom
+        from StringIO import StringIO
+        doc = minidom.parse(StringIO(doc))
+        print doc.toprettyxml()
 
 def render():
     Render().command()
